# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _


from . import models


class StoreAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'name', 'slug', 'description',),
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    search_fields = ('code', 'name')
    list_display = ('get_status_display', 'code', 'name', 'description', 'ordering',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)
    prepopulated_fields = {"slug": ("name",)}


class StoreDocumentAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'name', 'slug', 'description',),
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    search_fields = ('code', 'name')
    list_display = ('get_status_display', 'code', 'name', 'description', 'ordering',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)
    prepopulated_fields = {"slug": ("name",)}


class StoreDocumentNumberAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': (
                'store_document', 'application',
                'year', 'last_date', 'last_number'
            ),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    search_fields = ('store_document__name', 'application', 'year')
    list_display = ('store_document', 'application', 'year', 'last_date', 'last_number',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class StoreCauseAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': (
                'code', 'store', 'store_document', 'name', 'description',
                'category', 'move', 'ddt_required', 'invoice_required',
                'stock', 'busy', 'default',
            ),
        }),
        (_('visualization admin'), {
            'fields': ('status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    search_fields = ('code', 'name')
    list_display = (
        'get_status_display', 'code', 'name', 'store', 'store_document',
        'category', 'move', 'ddt_required', 'invoice_required',
        'stock', 'busy', 'default',
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


admin.site.register(models.Store, StoreAdmin)
admin.site.register(models.StoreDocument, StoreDocumentAdmin)
admin.site.register(models.StoreDocumentNumber, StoreDocumentNumberAdmin)
admin.site.register(models.StoreCause, StoreCauseAdmin)
