# -*- coding: utf-8 -*-

from rest_framework import generics

from thux.api.views import QuerysetMixin
from thux.api.permissions import ThuxModelPermissions

from .. import models
from . import serializers


class StoreList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Store.objects.all()
    serializer_class = serializers.StoreSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(StoreList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class StoreRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Store.objects.all()
    serializer_class = serializers.StoreSerializer


class StoreCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Store.objects.all()
    serializer_class = serializers.StoreSerializerCreate


class StoreUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.Store.objects.all()
    serializer_class = serializers.StoreSerializerUpdate


class StoreDocumentList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.StoreDocument.objects.all()
    serializer_class = serializers.StoreDocumentSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(StoreDocumentList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class StoreDocumentRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.StoreDocument.objects.all()
    serializer_class = serializers.StoreDocumentSerializer


class StoreDocumentCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.StoreDocument.objects.all()
    serializer_class = serializers.StoreDocumentSerializerCreate


class StoreDocumentUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.StoreDocument.objects.all()
    serializer_class = serializers.StoreDocumentSerializerUpdate


class StoreDocumentNumberList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.StoreDocumentNumber.objects.all()
    serializer_class = serializers.StoreDocumentNumberSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(StoreDocumentNumberList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class StoreDocumentNumberRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.StoreDocumentNumber.objects.all()
    serializer_class = serializers.StoreDocumentNumberSerializer


class StoreDocumentNumberCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.StoreDocumentNumber.objects.all()
    serializer_class = serializers.StoreDocumentNumberSerializerCreate


class StoreDocumentNumberUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.StoreDocumentNumber.objects.all()
    serializer_class = serializers.StoreDocumentNumberSerializerUpdate


class StoreCauseList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.StoreCause.objects.all()
    serializer_class = serializers.StoreCauseSerializer

    def get_queryset(self):
        filters = self.get_filters()
        excludes = self.get_excludes()
        order_by = self.get_order_by()
        queryset = super(StoreCauseList, self).get_queryset()
        queryset = queryset.filter(**filters).exclude(**excludes).order_by(*order_by).distinct()
        return queryset


class StoreCauseRetrieve(generics.RetrieveAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.StoreCause.objects.all()
    serializer_class = serializers.StoreCauseSerializer


class StoreCauseCreate(generics.CreateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.StoreCause.objects.all()
    serializer_class = serializers.StoreCauseSerializerCreate


class StoreCauseUpdate(generics.UpdateAPIView):
    permission_classes = (ThuxModelPermissions,)
    queryset = models.StoreCause.objects.all()
    serializer_class = serializers.StoreCauseSerializerUpdate
