# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Store',
            fields=[
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('default', models.BooleanField(default=False, verbose_name='Default')),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(max_length=15, serialize=False, verbose_name='code', primary_key=True)),
                ('name', models.CharField(unique=True, max_length=255, verbose_name='name')),
                ('slug', models.CharField(unique=True, max_length=255, verbose_name='slug')),
                ('description', models.TextField(null=True, verbose_name='description', blank=True)),
                ('creator', models.ForeignKey(related_name='store_store_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='store_store_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('ordering', 'name'),
                'verbose_name': 'store',
                'verbose_name_plural': 'stores',
                'permissions': (('list_store', 'Can list store'),),
            },
        ),
        migrations.CreateModel(
            name='StoreCause',
            fields=[
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('code', models.CharField(max_length=15, serialize=False, verbose_name='code', primary_key=True)),
                ('name', models.CharField(unique=True, max_length=255, verbose_name='name', db_index=True)),
                ('description', models.TextField(verbose_name='description', blank=True)),
                ('category', models.CharField(db_index=True, max_length=3, verbose_name='category', choices=[(b'com', 'company'), (b'cus', 'customer'), (b'sup', 'supplier'), (b'vec', 'vector'), (b'whe', 'warehouse')])),
                ('move', models.CharField(db_index=True, max_length=3, verbose_name='move', choices=[(b'not', 'not moving'), (b'in', 'in'), (b'out', 'out')])),
                ('ddt_required', models.BooleanField(default=False, db_index=True, verbose_name='ddt required')),
                ('invoice_required', models.BooleanField(default=False, db_index=True, verbose_name='ivoice required')),
                ('stock', models.IntegerField(db_index=True, verbose_name='stock', choices=[(0, b' '), (1, b'+'), (-1, b'-')])),
                ('busy', models.IntegerField(db_index=True, verbose_name='busy', choices=[(0, b' '), (1, b'+'), (-1, b'-')])),
                ('default', models.BooleanField(default=False, verbose_name='default')),
                ('creator', models.ForeignKey(related_name='store_storecause_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='store_storecause_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('store', models.ForeignKey(verbose_name='store', to='store.Store')),
            ],
            options={
                'verbose_name': 'store cause',
                'verbose_name_plural': 'store causes',
                'permissions': (('list_storecause', 'Can list store cause'),),
            },
        ),
        migrations.CreateModel(
            name='StoreDocument',
            fields=[
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('ordering', models.IntegerField(default=0, verbose_name='ordering')),
                ('code', models.CharField(max_length=15, serialize=False, verbose_name='code', primary_key=True)),
                ('name', models.CharField(unique=True, max_length=255, verbose_name='name')),
                ('slug', models.CharField(unique=True, max_length=255, verbose_name='slug')),
                ('description', models.TextField(verbose_name='description', blank=True)),
                ('creator', models.ForeignKey(related_name='store_storedocument_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='store_storedocument_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('ordering', 'name'),
                'verbose_name': 'store document',
                'verbose_name_plural': 'store documents',
                'permissions': (('list_storedocument', 'Can list store document'),),
            },
        ),
        migrations.CreateModel(
            name='StoreDocumentNumber',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('application', models.CharField(db_index=True, max_length=1, choices=[(b'q', 'quotation'), (b'p', 'procedure'), (b'd', 'ddt'), (b'i', 'invoice')])),
                ('year', models.PositiveIntegerField(verbose_name='year', db_index=True)),
                ('last_date', models.DateField(verbose_name='last date', db_index=True)),
                ('last_number', models.PositiveIntegerField(verbose_name='last number', db_index=True)),
                ('creator', models.ForeignKey(related_name='store_storedocumentnumber_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='store_storedocumentnumber_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('store_document', models.ForeignKey(related_name='document_numbers', verbose_name='store document', to='store.StoreDocument')),
            ],
            options={
                'verbose_name': 'store document number',
                'verbose_name_plural': 'store document numbers',
                'permissions': (('list_storedocumentnumber', 'Can list store document number'),),
            },
        ),
        migrations.AddField(
            model_name='storecause',
            name='store_document',
            field=models.ForeignKey(verbose_name='store document', blank=True, to='store.StoreDocument', null=True),
        ),
        migrations.AlterUniqueTogether(
            name='storedocumentnumber',
            unique_together=set([('store_document', 'year', 'application')]),
        ),
    ]
